@@ -2,14 +2,13 @@ var indexSectionsWithContent =
 {
   0: "abcdefghijlmnoprstuwxy",
   1: "j",
-  2: "bcdemprt",
+  2: "cdemprst",
   3: "jo",
   4: "abcdefghilmnoprstuwxy",
   5: "j",
   6: "j",
   7: "j",
-  8: "bj",
-  9: "d"
+  8: "acdefhijlmtx"
 };
 
 var indexSectionNames =
@@ -22,8 +21,7 @@ var indexSectionNames =
   5: "typedefs",
   6: "enums",
   7: "enumvalues",
-  8: "groups",
-  9: "pages"
+  8: "groups"
 };
 
 var indexSectionLabels =
@@ -36,7 +34,6 @@ var indexSectionLabels =
   5: "Typedefs",
   6: "Enumerations",
   7: "Enumerator",
-  8: "Modules",
-  9: "Pages"
+  8: "Modules"
 };
 
